<template>
  <div class="edit-add-detail">
    <div class="crumbs">
      <Breadcrumb
        :breadcrumbOpt="breadcrumbOpt"
        svg-name="#icon-bill"
        @breadcrumb-click="handleClose"
      />
    </div>
    <div class="form-content">
      <div class="company-information">
        <el-form
          ref="formInfo"
          :model="parameter"
          label-position="right"
          label-width="auto"
        >
          <div class="rows">
            <div class="rows-left">
              <div class="rows-hr"></div>
            </div>
            <div class="rows-title">
              <div class="text-overflow">基本信息</div>
            </div>
          </div>
          <el-row :gutter="24">
            <el-col :span="12">
              <el-form-item label="企业编号">
                <el-input
                  readonly
                  clearable
                  v-model="parameter.companyCode"
                ></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="企业名称">
                <el-input
                  readonly
                  clearable
                  v-model="parameter.companyName"
                ></el-input>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row :gutter="24">
            <el-col :span="12">
              <el-form-item label="采购商编号">
                <el-input
                  readonly
                  clearable
                  v-model="parameter.purchaserCode"
                ></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="采购商名称">
                <el-input
                  readonly
                  clearable
                  v-model="parameter.purchaserName"
                ></el-input>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row :gutter="24">
            <el-col :span="12">
              <el-form-item label="黑名单加入时间">
                <el-input
                  readonly
                  clearable
                  v-model="parameter.blacklistStartDate"
                ></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="黑名单到期时间">
                <el-input
                  readonly
                  clearable
                  v-model="parameter.blacklistExpireDate"
                ></el-input>
              </el-form-item>
            </el-col>
            
          </el-row>
          <el-row :gutter="24">
            <el-col :span="12">
              <el-form-item label="加入黑名单原因">
                <el-input
                  readonly
                  clearable
                  v-model="parameter.blacklistReason"
                ></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="状态">
                <dict-select
                  dictCode="hmd-zt"
                  :hasDefaultOption="true"
                  clearable
                  style="width:100%"
                  v-model="parameter.blacklistStatus"
                  placeholder="请选择状态"
                />
              </el-form-item>
            </el-col>
            
          </el-row>
          <!-- <el-row :gutter="24">
            <el-col :span="12">
              <el-form-item label="供应商性质">
                <el-input
                  readonly
                  clearable
                  v-model="parameter.clientName"
                ></el-input>
              </el-form-item>
            </el-col>
          </el-row> -->
          <div class="rows">
            <div class="rows-left">
              <div class="rows-hr"></div>
            </div>
            <div class="rows-title">
              <div class="text-overflow">附件</div>
            </div>
          </div>
          
        </el-form>
      </div>
    </div>
  </div>
</template>

<script>
import supplierManger from '@/api/supplierManger.js'
import Breadcrumb from '@/components/Breadcrumb/index.vue'
import utils from '@/utils.js'
export default {
  name: 'evaluationDetail',
  components: {Breadcrumb},
  data() {
    return {
      breadcrumbOpt: [
        {breadcrumbName: '企业评价'},
        {breadcrumbName: '详情'}
      ],
      parameter: {}
    }
  },
  created() {
    let {id} = this.$route.params
    this.getByIdData(id)
  },
  methods: {
    getByIdData(id) {
      let formData = new FormData()
      formData.append('id', id)
      supplierManger.getByIdBlacklist(formData).then(res => {
        this.parameter = res.data.value || {}
      })
    },
    // 关闭//面包屑点击
    handleClose() {
      this.$router.push({
        name: 'enterpriseEvaluation',
        params: {
          pageBean: this.$route.query.pageBean
        }
      })
      this.parameter = {}
    },
    //详情
    detail(val) {
      if (val) {
        this.modifychoData(val)
      }
    },
    //获取详情
    modifychoData(val) {}
  }
}
</script>
<style lang="scss" scoped>
::v-deep .el-form-item__label {
  width: 120px;
  font-size: 14px;
  color: #828282;
  font-weight: 500;
}

::v-deep .el-form-item__content span {
  font-size: 14px;
  color: #000;
  font-weight: 500;
}

::v-deep .el-form-item {
  margin-bottom: 10px;
}
.rows {
  display: flex;
  align-items: center;
  border-bottom: 1px solid #ebebeb;
  margin-bottom: 16px;
  padding: 10px 0;

  .rows-left {
    margin-right: 10px;

    .rows-hr {
      width: 3px;
      height: 18px;
      background-color: #0e6eff;
      border-radius: 2px;
    }
  }

  .rows-title {
    .text-overflow {
      width: 100%;
      font-size: 16px;
    }
  }
}
</style>
